#include <avr/io.h>

#include "Arduino.h"
#include "config.h"
#include "def.h"
#include "types.h"
#include "MultiWii.h"
#include "Alarms.h"
#include "EEPROM.h"
#include "IMU.h"
#include "LCD.h"
#include "Output.h"
#include "RX.h"
#include "Sensors.h"
#include "Serial.h"
#include "GPS.h"
#include "Protocol.h"

#include <avr/pgmspace.h>


#define BTN_UP     2
#define BTN_DOWN   4
#define BTN_LEFT   5
#define BTN_RIGHT  6
#define BTN_MIDDLE 7
#define BTN_RST    9
#define BTN_SET    10

#define LED1    3
#define LED2    A0
#define LED3    A1
#define LED4    A2

// uint32_t ONE_STEP = 240000; // Full 240 ms
uint32_t ONE_STEP = 120000; // Half 120 ms
uint32_t nOldMicro = 0, nNewMicro = 0;

uint8_t lLATRev = 0, nLATRevLock = 0;

void setup() {
  pinMode(BTN_UP, INPUT_PULLUP);
  pinMode(BTN_DOWN, INPUT_PULLUP);
  pinMode(BTN_LEFT, INPUT_PULLUP);
  pinMode(BTN_RIGHT, INPUT_PULLUP);
  pinMode(BTN_MIDDLE, INPUT_PULLUP);
  pinMode(BTN_RST, INPUT_PULLUP);
  pinMode(BTN_SET, INPUT_PULLUP);

  pinMode(LED1, OUTPUT);
  pinMode(LED2, OUTPUT);
  pinMode(LED3, OUTPUT);
  pinMode(LED4, OUTPUT);

  SerialOpen(0, SERIAL0_COM_SPEED);

  nOldMicro = micros();
  nNewMicro = nOldMicro;
}

void loop() {
  int nUp = digitalRead(BTN_UP);
  int nDown = digitalRead(BTN_DOWN);
  int nLeft = digitalRead(BTN_LEFT);
  int nRight = digitalRead(BTN_RIGHT);
  int nMiddle = digitalRead(BTN_MIDDLE);
  int nRST = digitalRead(BTN_RST);
  int nSet = digitalRead(BTN_SET);

  nNewMicro = micros();
  if ((nNewMicro - nOldMicro) > (ONE_STEP * 1))
  {
    unsigned long nLonStep = (nNewMicro - nOldMicro) / ONE_STEP;
    nOldMicro += nLonStep * ONE_STEP;

    if (nLeft == 0)
    {
      MSPTelescopeLON(1, 0, 1);
    }

    if (nRight == 0)
    {
      MSPTelescopeLON(0, 0, 1);
    }

    if (nUp == 0)
    {
      if (lLATRev == 0)
        MSPTelescopeLAT(1, 0, 1);
      else
        MSPTelescopeLAT(0, 0, 1);
    }

    if (nDown == 0)
    {
      if (lLATRev == 0)
        MSPTelescopeLAT(0, 0, 1);
      else
        MSPTelescopeLAT(1, 0, 1);
    }

    if (nLATRevLock == 0)
    {
      if (nSet == 0)
      {
        if (lLATRev == 0)
        {
          lLATRev = 1;
        }
        else
        {
          lLATRev = 0;
        }
        nLATRevLock = 5;

        MSPTelescopeLATRev(lLATRev == 0 ? 0 : 1);
      }
      // MSPTelescopeLATRev(lLATRev == 0 ? 0 : 1);
    }
    else
    {
      if (nLATRevLock > 0 && nLATRevLock <= 5)
      {
        nLATRevLock --;
      }
      else
      {
        nLATRevLock = 5;
      }
    }
  }

  digitalWrite(LED1, lLATRev);
  digitalWrite(LED2, lLATRev);
  digitalWrite(LED3, lLATRev);
  digitalWrite(LED4, lLATRev);

  delay(1);        // delay in between reads for stability
}
